==> haskell-slist-0.2.1.0-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-slist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 slist
version:              0.2.1.0
visibility:           public
id:                   slist-0.2.1.0-1L0o7eaOqE03Zo2lwoFwYx
key:                  slist-0.2.1.0-1L0o7eaOqE03Zo2lwoFwYx
license:              MPL-2.0
copyright:
    2019-2020 Veronika Romashkina
    2020-2022 Kowainik

maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina
homepage:             https://github.com/kowainik/slist
synopsis:             Sized list
description:
    This package implements @Slist@ data structure that stores the size
    of the list along with the list itself.

category:             Data Structures, List
abi:                  a8cf4d8de8e63da37b61c7f6ba904f52
exposed:              True
exposed-modules:
    Slist Slist.Containers Slist.Maybe Slist.Size Slist.Type

import-dirs:          /usr/lib/ghc-9.4.8/site-local/slist-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/slist-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/slist-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-slist
hs-libraries:         HSslist-0.2.1.0-1L0o7eaOqE03Zo2lwoFwYx
depends:              base-4.17.2.1 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-slist/html/slist.haddock
haddock-html:         /usr/share/doc/haskell-slist/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-slist-0.2.1.0-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-slist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 slist
version:              0.2.1.0
visibility:           public
id:                   slist-0.2.1.0-B2uyh2SeVYvKk9xw7ZeFaM
key:                  slist-0.2.1.0-B2uyh2SeVYvKk9xw7ZeFaM
license:              MPL-2.0
copyright:
    2019-2020 Veronika Romashkina
    2020-2022 Kowainik

maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina
homepage:             https://github.com/kowainik/slist
synopsis:             Sized list
description:
    This package implements @Slist@ data structure that stores the size
    of the list along with the list itself.

category:             Data Structures, List
abi:                  43e2a9c37664c438b0d81dbb6eb7f76f
exposed:              True
exposed-modules:
    Slist Slist.Containers Slist.Maybe Slist.Size Slist.Type

import-dirs:          /usr/lib/ghc-9.4.8/site-local/slist-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/slist-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/slist-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-slist
hs-libraries:         HSslist-0.2.1.0-B2uyh2SeVYvKk9xw7ZeFaM
depends:              base-4.17.2.1 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-slist/html/slist.haddock
haddock-html:         /usr/share/doc/haskell-slist/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
